--[[
	This is Ezarras ZoneLevel, based on Zone Level by Fanook
	Additions to this version include 1) More zones, 2) a tooltip window showing 
	the low and high levels for a zone when you mouse over the ZoneLevel icon, and
	a Message to the chat window when changing zones showing the low and high 
	levels.  Zome zones have the levels slightly tweaked to give more realistic
	information on the actual level of a zone 
	
	The Zones are all alphabetized for easy searching and reference.
-- ]]

local EZLL; --// the low data
local EZLH; --// the high data
local ZL_low; --// the lowest level
local ZL_high; --// The highest level
local level; --// The player level
local zoneColor   = ""; --// The Color commands for the zone
local zone        = ""; --// The SubZone or RealZone
local LastChatSpam= "";
local EZLGrey     = "|cff999999";
local EZLRed      = "|cffff0000";
local EZLGreen    = "|cff00ff00";
local EZLYellow   = "|cffffff00";
local EZLWhite    = "|cffffffff";
local text        = "";
-- //Set Default 

function EZoneLevel_Command(msg)
    -- // We don't care about caps
    msg = string.lower(msg);
    
    if ( (string.find(msg, 'on'))) then
        ChatSpam = 1;
        ChatFrame1:AddMessage(EZLYellow.."EZoneLevel ChatSpam|r"..EZLRed.." Enabled");
    elseif ( (string.find(msg, 'off'))) then
        ChatSpam = 0;
        ChatFrame1:AddMessage(EZLYellow.."EZoneLevel ChatSpam|r"..EZLRed.." Disabled");
    elseif ( (string.find(msg, 'unk'))) then
        ChatSpam = 2;
        ChatFrame1:AddMessage(EZLYellow.."EZoneLevel ChatSpam|r"..EZLRed.." Unknown");
    elseif ( (string.find(msg, 'sta'))) then
        if (ChatSpam == 1) then
            ChatFrame1:AddMessage(EZLYellow.."EZoneLevel ChatSpam|r"..EZLRed.." Enabled");
        elseif (ChatSpam == 0) then
            ChatFrame1:AddMessage(EZLYellow.."EZoneLevel ChatSpam|r"..EZLRed.." Disabled");
        elseif (ChatSpam == 2) then
            ChatFrame1:AddMessage(EZLYellow.."EZoneLevel ChatSpam|r"..EZLRed.." Unknown");
        end
    elseif ( (string.find(msg, 'tog'))) then
        if (ChatSpam == 1) then
            ChatSpam = 0;
            ChatFrame1:AddMessage(EZLYellow.."EZoneLevel ChatSpam|r"..EZLRed.." Disabled");
        else
            ChatSpam = 1;
            ChatFrame1:AddMessage(EZLYellow.."EZoneLevel ChatSpam|r"..EZLRed.." Enabled");
        end
    else
         ChatFrame1:AddMessage(EZLRed.."/ezl on|r "..EZLYellow.."turns on ChatSpam");
         ChatFrame1:AddMessage(EZLRed.."/ezl off|r "..EZLYellow.."turns off ChatSpam");
         ChatFrame1:AddMessage(EZLRed.."/ezl unknown|r "..EZLYellow.."turns ChatSpam on only for unknown areas");
         ChatFrame1:AddMessage(EZLRed.."/ezl status|r "..EZLYellow.."shows current state");
         ChatFrame1:AddMessage(EZLRed.."/ezl toggle|r "..EZLYellow.."Toggles ChatSpam ");
         ChatFrame1:AddMessage(EZLRed.."ON|r or "..EZLRed.."OFF|r "..EZLYellow.."(toggles "..EZLRed.."UNKNOWN|r "..EZLYellow.."to ON)");
    end
    RegisterForSave("ChatSpam");
end

function EZoneLevel_OnEnter()
    GameTooltip:SetOwner(EZoneLevel_Base, "ANCHOR_NONE");
    GameTooltip:SetPoint("TOP", "UIParent", "TOPRIGHT", -265, -20);
    EZoneLevel_SetTooltip();
end

-- //Load/initialization function
function EZoneLevel_OnLoad()

    -- //Register for events
    this:RegisterEvent("MINIMAP_ZONE_CHANGED");
    
    if( DEFAULT_CHAT_FRAME ) then
        DEFAULT_CHAT_FRAME:AddMessage(EZLRed.."Ezarra's|r ZoneLevel Loaded\n"..EZLYellow.."/ezl help|r for help");
    end
    
    UIErrorsFrame:AddMessage("EZone Level AddOn loaded", 1.0, 1.0, 1.0, 1.0, UIERRORS_HOLD_TIME);
    
    --//Register Slash Commands
    SlashCmdList["EZONE"] = EZoneLevel_Command;
    SLASH_EZONE1 = "/ezl";
    SLASH_EZONE2 = "/ezonelevel";
     if(myAddOnsFrame) then
     	myAddOnsList.EZoneLevel = {name = "EZoneLevel", description = "Adds a relative safety graphical indicator of mob levels in a zone; /ezl for help", version = "1.8", category = MYADDONS_CATEGORY_MAP, frame = "EZoneLevel_Base"};
	end
    this:RegisterEvent("VARIABLES_LOADED");
       
    -- // Construct tables to hold level information for each zone
    EZLL={};
    EZLH={};
    EZoneLevel_MakeTables();
    
    -- // Rest Previous message
    LastChatSpam = "";
    
end

-- //Event handler for ZoneLevel
function EZoneLevel_OnEvent()
    level = UnitLevel("player");
    zone=GetSubZoneText();
    if ((zone == "") or (EZLL[zone] == -6)) then 
       zone=GetZoneText();
    end
    ZL_low = EZLL[zone];
    text = "";
    unknown = 0;
    if ( ZL_low == nil ) then
        if (zone ~= "") then
            text = EZLRed.."Levels for Zone \""..zone.."\" unknown|r, ";
            unknown = 1;
        end
        zone=GetZoneText();
        ZL_low = EZLL[zone];
        ZL_high = EZLH[zone];
        text = text .."using "..zone.." levels.\n";
        EZoneLevel_Grey:Show();
        EZoneLevel_Green:Hide();
        EZoneLevel_Yellow:Hide();
        EZoneLevel_Red:Hide();
        if (ChatSpam == 2 )  then
            if (text ~= LastChatSpam) then
                   ChatFrame1:AddMessage(text);
                   LastChatSpam = text;
            end
        end
    else
        ZL_high = EZLH[zone];
        local mid = (ZL_low + ZL_high)/2;
        if(ZL_high < level-5) then -- Grey icon
            EZoneLevel_Grey:Show();
            EZoneLevel_Green:Hide();
            EZoneLevel_Yellow:Hide();
            EZoneLevel_Red:Hide();
            zoneColor = EZLGrey;
        elseif(ZL_low > level) then -- Red icon
            EZoneLevel_Grey:Hide();
            EZoneLevel_Green:Hide();
            EZoneLevel_Yellow:Hide();
            EZoneLevel_Red:Show();
            zoneColor = EZLRed;
        elseif(mid < level) then -- Green icon
            EZoneLevel_Grey:Hide();
            EZoneLevel_Green:Show();
            EZoneLevel_Yellow:Hide();
            EZoneLevel_Red:Hide();
            zoneColor = EZLGreen;
        else -- Yellow icon
            EZoneLevel_Grey:Hide();
            EZoneLevel_Green:Hide();
            EZoneLevel_Yellow:Show();
            EZoneLevel_Red:Hide();
            zoneColor = EZLYellow;
        end
    end
    if (zoneColor == "") then
        zoneColor = EZLWhite;
    end
    if (ChatSpam ~= 0) then
        text = zone.."|r ";
    else
        text = zone.." ";
    end
    if (ZL_low ~= nil) then
        text = text.."("..ZL_low;
    end
    if (ZL_high ~= nil) then
        text = text.."/"..ZL_high..")";
    end
    if ( ChatSpam == 2 ) then
        if (unknown == 1 )  then
             if (text ~= LastChatSpam) then
                   ChatFrame1:AddMessage(zoneColor..text);
                   LastChatSpam = text;
            end
        end
    elseif (ChatSpam ~= 0) then
         if (text ~= LastChatSpam) then
             --// Testing
             --// ChatFrame1:AddMessage("Text is: \""..text.."\"");
             if (zoneColor ~= "") then
                ChatFrame1:AddMessage(zoneColor..text);
                   LastChatSpam = text;
               elseif (text ~= "") then
                   ChatFrame1:AddMessage(text);
                   LastChatSpam = text;
               end
        end
    end
end

function EZoneLevel_SetTooltip()
    level = UnitLevel("player");
    zone=GetSubZoneText();
     if ((zone == "") or (EZLL[zone] == -6)) then 
       zone=GetZoneText();
    end
    ZL_low = EZLL[zone];
    if ( ZL_low == nil ) then
        zone=GetZoneText();
        ZL_low = EZLL[zone];
    else
          ZL_high = EZLH[zone];
          local mid = (ZL_low + ZL_high)/2;
        if(ZL_high < level-5) then -- Grey icon
            zoneColor = EZLGrey;
        elseif(ZL_low > level) then -- Red icon
            zoneColor = EZLRed;
        elseif(mid < level) then -- Green icon
            zoneColor = EZLGreen;
        else -- Yellow icon
            zoneColor = EZLYellow;
        end
       end
    if (zoneColor ~= "") then
        text = zoneColor;
    else
        text = EZLWhite;
    end
    text = text..zone.."|r\n";
    if (ZL_low ~= nil) then
        text = text.."Low  : "..ZL_low;
    end
   if (ZL_low ~= nil) then
        text = text.."\nHigh : "..ZL_high;
    end
    GameTooltip:SetText(text);
end


-- //Makes tables containing level ranges for each zone
function EZoneLevel_MakeTables()
    EZLH["Abyssal Sands"]=54;
    EZLL["Abyssal Sands"]=41;
    EZLH["Addle's Stead"]=26;
    EZLL["Addle's Stead"]=19;
    EZLH["Aerie Peak"]=41;
    EZLL["Aerie Peak"]=41;
    EZLH["Agama'gor"]=22;
    EZLL["Agama'gor"]=13;
    EZLH["Agamand Family Crypt"]=13;
    EZLL["Agamand Family Crypt"]=9;
    EZLH["Agamand Mills"]=11;
    EZLL["Agamand Mills"]=6;
    EZLH["Agmond's End"]=43;
    EZLL["Agmond's End"]=37;
    EZLH["Agnor Fortress"]=39;
    EZLL["Agnor Fortress"]=35;
    EZLH["Agol'watha"]=48;
    EZLL["Agol'watha"]=43;
    EZLH["Alexston Farmstead"]=19;
    EZLL["Alexston Farmstead"]=11;
    EZLH["Algaz Station"]=12;
    EZLL["Algaz Station"]=10;
    EZLH["Altar of Storms"]=57;
    EZLL["Altar of Storms"]=53;
    EZLH["Alterac Mountains"]=37;
    EZLL["Alterac Mountains"]=21;
    EZLH["Alterac Valley"]=50;
    EZLL["Alterac Valley"]=30;
    EZLH["Alther's Mill"]=21;
    EZLL["Alther's Mill"]=16;
    EZLH["Ambermill"]=21;
    EZLL["Ambermill"]=12;
    EZLH["Amberstill Ranch"]=12;
    EZLL["Amberstill Ranch"]=6;
    EZLH["Ameth'aran"]=16;
    EZLL["Ameth'aran"]=10;
    EZLH["Angerfang Encampment"]=32;
    EZLL["Angerfang Encampment"]=24;
    EZLH["Angor Fortress"]=39;
    EZLL["Angor Fortress"]=35;
    EZLH["Apocryphan's Rest"]=41;
    EZLL["Apocryphan's Rest"]=39;
    EZLH["Arathi Highlands"]=50;
    EZLL["Arathi Highlands"]=30;
    EZLH["Ashenvale"]=40;
    EZLL["Ashenvale"]=18;
    EZLH["Astranaar"]=37;
    EZLL["Astranaar"]=19;
    EZLH["Auberdine"]=-6;
    EZLL["Auberdine"]=-6;
    EZLH["Azshara"]=55;
    EZLL["Azshara"]=44;
    EZLH["Azurelode Mine"]=30;
    EZLL["Azurelode Mine"]=24;
    EZLH["Badlands"]=55;
    EZLL["Badlands"]=35;
    EZLH["Bael Modan"]=30;
    EZLL["Bael Modan"]=22;
    EZLH["Bael'dun Keep"]=30;
    EZLL["Bael'dun Keep"]=23;
    EZLH["Bael'dunigsite"]=9;
    EZLL["Bael'dunigsite"]=7;
    EZLH["Bal'lal Ruins"]=55;
    EZLL["Bal'lal Ruins"]=32;
    EZLH["Balia'mah Ruins"]=42;
    EZLL["Balia'mah Ruins"]=37;
    EZLH["Balnir Farmstead"]=11;
    EZLL["Balnir Farmstead"]=7;
    EZLH["Baradin Bay"]=22;
    EZLL["Baradin Bay"]=20;
    EZLH["Barrowens"]=52;
    EZLL["Barrowens"]=50;
    EZLH["Bashal'Aran"]=17;
    EZLL["Bashal'Aran"]=10;
    EZLH["Bathran's Haunt"]=20;
    EZLL["Bathran's Haunt"]=19;
    EZLH["Bay of Storms"]=60;
    EZLL["Bay of Storms"]=52;
    EZLH["Bear's Head"]=53;
    EZLL["Bear's Head"]=46;
    EZLH["Beggar's Haunt"]=-6;
    EZLL["Beggar's Haunt"]=-6;
    EZLH["Beren's Peril"]=21;
    EZLL["Beren's Peril"]=19;
    EZLH["Bitter Reaches"]=55;
    EZLL["Bitter Reaches"]=52;
    EZLH["Black Channel Marsh"]=25;
    EZLL["Black Channel Marsh"]=20;
    EZLH["Blackfathom Deeps"]=27
    EZLL["Blackfathom Deeps"]=20
    EZLH["Blackfathomeeps"]=30;
    EZLL["Blackfathomeeps"]=18;
    EZLH["Blackrock Depths"]=56
    EZLL["Blackrock Depths"]=48
    EZLH["Blackrock Mountain"]=58;
    EZLL["Blackrock Mountain"]=46;
    EZLH["Blackrock Pass"]=53;
    EZLL["Blackrock Pass"]=51;
    EZLH["Blackrock Spire"]=55;
    EZLH["Blackrock Spire"]=60
    EZLL["Blackrock Spire"]=53;
    EZLL["Blackrock Spire"]=53
    EZLH["Blackrock Stronghold"]=58;
    EZLL["Blackrock Stronghold"]=54;
    EZLH["Blackthorn Ridge"]=26;
    EZLL["Blackthorn Ridge"]=20;
    EZLH["Blackwater Cove"]=-6;
    EZLL["Blackwater Cove"]=-6;
    EZLH["Blackwater Shipwrecks"]=-6;
    EZLL["Blackwater Shipwrecks"]=-6;
    EZLH["Blackwolf River"]=25;
    EZLL["Blackwolf River"]=18;
    EZLH["Blackwood Lake"]=58;
    EZLL["Blackwood Lake"]=54;
    EZLH["Blackwooden"]=20;
    EZLL["Blackwooden"]=16;
    EZLH["Bladefist Bay"]=10;
    EZLL["Bladefist Bay"]=5;
    EZLH["Blasted Lands"]=57;
    EZLL["Blasted Lands"]=45;
    EZLH["Bloodhoof Village"]=14;
    EZLL["Bloodhoof Village"]=5;
    EZLH["Bloodsail Compound"]=43;
    EZLL["Bloodsail Compound"]=40;
    EZLH["Bloodvenom Falls"]=56;
    EZLL["Bloodvenom Falls"]=49;
    EZLH["Bloodvenom Post"]=62;
    EZLL["Bloodvenom Post"]=55;
    EZLH["Bloodvenom River"]=62;
    EZLL["Bloodvenom River"]=49;
    EZLH["Bluefen"]=37;
    EZLL["Bluefen"]=35;
    EZLH["Bluegill Marsh"]=25;
    EZLL["Bluegill Marsh"]=20;
    EZLH["Bogen's Ledge"]=45;
    EZLL["Bogen's Ledge"]=42;
    EZLH["Bolgan's Hole"]=37;
    EZLL["Bolgan's Hole"]=33;
    EZLH["Booty Bay"]=60;
    EZLL["Booty Bay"]=30;
    EZLH["Bough Shadow"]=62;
    EZLL["Bough Shadow"]=61;
    EZLH["Boulder Load Mine"]=-6;
    EZLL["Boulder Load Mine"]=-6;
    EZLH["Boulder Lode Mine"]=19;
    EZLL["Boulder Lode Mine"]=14;
    EZLH["Boulder'gor"]=50;
    EZLL["Boulder'gor"]=30;
    EZLH["Boulderfist Hall"]=39;
    EZLL["Boulderfist Hall"]=35;
    EZLH["Boulderfist Outpost"]=36;
    EZLL["Boulderfist Outpost"]=33;
    EZLH["Boulderslide Ravine"]=20;
    EZLL["Boulderslide Ravine"]=16;
    EZLH["Brackenwall Village"]=55;
    EZLL["Brackenwall Village"]=36;
    EZLH["Brackwell Pumpkin Patch"]=10;
    EZLL["Brackwell Pumpkin Patch"]=7;
    EZLH["Bramblescar"]=26;
    EZLL["Bramblescar"]=16;
    EZLH["Brave Wind Mesa"]=-6;
    EZLL["Brave Wind Mesa"]=-6;
    EZLH["Brewnall Village"]=8;
    EZLL["Brewnall Village"]=7;
    EZLH["Brightwater Lake"]=16;
    EZLL["Brightwater Lake"]=6;
    EZLH["Brightwood Grove"]=29;
    EZLL["Brightwood Grove"]=20;
    EZLH["Brill"]=7;
    EZLL["Brill"]=5;
    EZLH["Broken Pillar"]=48;
    EZLL["Broken Pillar"]=43;
    EZLH["Browman Mill"]=60;
    EZLL["Browman Mill"]=55;
    EZLH["Bucklebree Farm"]=-6;
    EZLL["Bucklebree Farm"]=-6;
    EZLH["Burning Blade Coven"]=5;
    EZLL["Burning Blade Coven"]=3;
    EZLH["Burning Steppes"]=58;
    EZLL["Burning Steppes"]=50;
    EZLH["Caerarrow"]=-6;
    EZLL["Caerarrow"]=-6;
    EZLH["Camp Aparaje"]=17;
    EZLL["Camp Aparaje"]=14;
    EZLH["Camp Boff"]=43;
    EZLL["Camp Boff"]=36;
    EZLH["Camp Cagg"]=45;
    EZLL["Camp Cagg"]=36;
    EZLH["Camp E'thok"]=30;
    EZLL["Camp E'thok"]=26;
    EZLH["Camp Kosh"]=35;
    EZLL["Camp Kosh"]=35;
    EZLH["Camp Mojache"]=65;
    EZLL["Camp Mojache"]=30;
    EZLH["Camp Taurajo"]=40;
    EZLL["Camp Taurajo"]=15;
    EZLH["Camp Wurg"]=43;
    EZLL["Camp Wurg"]=36;
    EZLH["Caverns of Time"]=50;
    EZLL["Caverns of Time"]=50;
    EZLH["Chill Breeze Valley"]=11;
    EZLL["Chill Breeze Valley"]=6;
    EZLH["Chillwind Point"]=58;
    EZLL["Chillwind Point"]=30;
    EZLH["Circle of East Binding"]=42;
    EZLL["Circle of East Binding"]=30;
    EZLH["Circle of Inner Binding"]=42;
    EZLL["Circle of Inner Binding"]=30;
    EZLH["Circle of Outer Binding"]=42;
    EZLL["Circle of Outer Binding"]=30;
    EZLH["Circle of West Binding"]=39;
    EZLL["Circle of West Binding"]=30;
    EZLH["Cliffspring Falls"]=17;
    EZLL["Cliffspring Falls"]=13;
    EZLH["Cliffspring River"]=20;
    EZLL["Cliffspring River"]=13;
    EZLH["Cold Hearth Manor"]=9;
    EZLL["Cold Hearth Manor"]=5;
    EZLH["Coldridge Pass"]=6;
    EZLL["Coldridge Pass"]=1;
    EZLH["Coldridge Valley"]=5;
    EZLL["Coldridge Valley"]=1;
    EZLH["Corin's Crossing"]=58;
    EZLL["Corin's Crossing"]=54;
    EZLH["Corrahn'sagger"]=34;
    EZLL["Corrahn'sagger"]=20;
    EZLH["Cragpool Lake"]=27;
    EZLL["Cragpool Lake"]=18;
    EZLH["Crown Guard Tower"]=55;
    EZLL["Crown Guard Tower"]=53;
    EZLH["Crusader Outpost"]=11;
    EZLL["Crusader Outpost"]=7;
    EZLH["Crusader's Outpost"]=7;
    EZLL["Crusader's Outpost"]=6;
    EZLH["Crushridge Hold"]=36;
    EZLL["Crushridge Hold"]=35;
    EZLH["Crystal Lake"]=9;
    EZLL["Crystal Lake"]=5;
    EZLH["Crystalvein Mine"]=42;
    EZLL["Crystalvein Mine"]=41;
    EZLH["Dabyrie's Farmstead"]=35;
    EZLL["Dabyrie's Farmstead"]=30;
    EZLH["Dalaran"]=35;
    EZLL["Dalaran"]=24;
    EZLH["Dalson's Tears"]=56;
    EZLL["Dalson's Tears"]=50;
    EZLH["Dandred's Fold"]=40;
    EZLL["Dandred's Fold"]=30;
    EZLH["Dark Portal"]=61;
    EZLL["Dark Portal"]=49;
    EZLH["Darkcloud Pinnacle"]=34;
    EZLL["Darkcloud Pinnacle"]=24;
    EZLH["Darkshire"]=40;
    EZLL["Darkshire"]=2;
    EZLH["Darkshore"]=28;
    EZLL["Darkshore"]=9;
    EZLH["Darkspear Strand"]=8;
    EZLL["Darkspear Strand"]=1;
    EZLH["Darkwhisper Gorge"]=60;
    EZLL["Darkwhisper Gorge"]=59;
    EZLH["Darnassus"]=-6;
    EZLL["Darnassus"]=-6;
    EZLH["Darrow Hill"]=32;
    EZLL["Darrow Hill"]=22;
    EZLH["Darrowmere Lake"]=60;
    EZLL["Darrowmere Lake"]=12;
    EZLH["Darrowshire"]=55;
    EZLL["Darrowshire"]=53;
    EZLH["Dawning Wood Catacombs"]=29;
    EZLL["Dawning Wood Catacombs"]=25;
    EZLH["Deadeye Shore"]=8;
    EZLL["Deadeye Shore"]=2;
    EZLH["Deadman's Crossing"]=56;
    EZLL["Deadman's Crossing"]=55;
    EZLH["Deadmines"]=20
    EZLL["Deadmines"]=15
    EZLH["Deadwind Pass"]=56;
    EZLL["Deadwind Pass"]=55;
    EZLH["Deadwood Village"]=53;
    EZLL["Deadwood Village"]=47;
    EZLH["Deathknell"]=5;
    EZLL["Deathknell"]=1;
    EZLH["Deep Elem Mine"]=15;
    EZLL["Deep Elem Mine"]=11;
    EZLH["Demon Fall Canyon"]=30;
    EZLL["Demon Fall Canyon"]=29;
    EZLH["Demon Fall Ridge"]=-6;
    EZLL["Demon Fall Ridge"]=-6;
    EZLH["Demonic Stronghold"]=-6;
    EZLL["Demonic Stronghold"]=-6;
    EZLH["Demont's Place"]=17;
    EZLL["Demont's Place"]=14;
    EZLH["Desolace"]=40;
    EZLL["Desolace"]=30;
    EZLH["Dire Maul"]=47;
    EZLL["Dire Maul"]=43;
    EZLH["Direforge Hill"]=-6;
    EZLL["Direforge Hill"]=-6;
    EZLH["Draco'dar"]=58;
    EZLL["Draco'dar"]=55;
    EZLH["Dragonmaw Gates"]=-6;
    EZLL["Dragonmaw Gates"]=-6;
    EZLH["Dreadmaul Hold"]=58;
    EZLL["Dreadmaul Hold"]=45;
    EZLH["Dreadmaul Post"]=55;
    EZLL["Dreadmaul Post"]=50;
    EZLH["Dreadmaul Rock"]=56;
    EZLL["Dreadmaul Rock"]=50;
    EZLH["Dreadmist Peak"]=25;
    EZLL["Dreadmist Peak"]=10;
    EZLH["Dreadmisten"]=15;
    EZLL["Dreadmisten"]=10;
    EZLH["Dreadmurk Shore"]=38;
    EZLL["Dreadmurk Shore"]=35;
    EZLH["Dream Bough"]=62;
    EZLL["Dream Bough"]=62;
    EZLH["Drygulch Ravine"]=11;
    EZLL["Drygulch Ravine"]=5;
    EZLH["Drywhisker Gorge"]=38;
    EZLL["Drywhisker Gorge"]=35;
    EZLH["Dun Algaz"]=22;
    EZLL["Dun Algaz"]=11;
    EZLH["Dun Baldar"]=-6;
    EZLH["Dun Garok"]=32;
    EZLL["Dun Garok"]=24;
    EZLH["Dun Mandarr"]=59;
    EZLL["Dun Mandarr"]=56;
    EZLH["Dun Modr"]=34;
    EZLL["Dun Modr"]=27;
    EZLH["Dun Morogh"]=12;
    EZLL["Dun Morogh"]=5;
    EZLH["Dunemaul Compound"]=50;
    EZLL["Dunemaul Compound"]=43;
    EZLH["Durnholde Keep"]=40;
    EZLL["Durnholde Keep"]=20;
    EZLH["Durotar"]=45;
    EZLL["Durotar"]=1;
    EZLH["Duskwood"]=40;
    EZLL["Duskwood"]=18;
    EZLH["Dustbelch Grotto"]=-6;
    EZLL["Dustbelch Grotto"]=-6;
    EZLH["Dustwallow Bay"]=43;
    EZLL["Dustwallow Bay"]=35;
    EZLH["Dustwallow Marsh"]=55;
    EZLL["Dustwallow Marsh"]=22;
    EZLH["Dustwind Cave"]=11;
    EZLL["Dustwind Cave"]=8;
    EZLH["Dustwind Gulch"]=40;
    EZLL["Dustwind Gulch"]=35;
    EZLH["East Pillar"]=-6;
    EZLL["East Pillar"]=-6;
    EZLH["Eastern Plaguelands"]=60;
    EZLL["Eastern Plaguelands"]=12;
    EZLH["Eastern Strand"]=32;
    EZLL["Eastern Strand"]=26;
    EZLH["Eastmoon Ruins"]=48;
    EZLL["Eastmoon Ruins"]=43;
    EZLH["Eastvale Logging Camp"]=10;
    EZLL["Eastvale Logging Camp"]=8;
    EZLH["Eastwall Gate"]=57;
    EZLL["Eastwall Gate"]=56;
    EZLH["Eastwall Tower"]=59;
    EZLL["Eastwall Tower"]=56;
    EZLH["Echo Isles"]=10;
    EZLL["Echo Isles"]=2;
    EZLH["Echo Ridge Mine"]=8;
    EZLL["Echo Ridge Mine"]=3;
    EZLH["Elwynn Forest"]=12;
    EZLL["Elwynn Forest"]=1;
    EZLH["Emberstrife'sen"]=61;
    EZLL["Emberstrife'sen"]=61;
    EZLH["Emerald Sanctuary"]=49;
    EZLL["Emerald Sanctuary"]=47;
    EZLH["Ethel Rethor"]=35;
    EZLL["Ethel Rethor"]=31;
    EZLH["Everlook"]=60;
    EZLL["Everlook"]=30;
    EZLH["Faldir's Cove"]=40;
    EZLL["Faldir's Cove"]=39;
    EZLH["Falfarren River"]=28;
    EZLL["Falfarren River"]=24;
    EZLH["Fallen Sky Lake"]=30;
    EZLL["Fallen Sky Lake"]=19;
    EZLH["Fallow Sanctuary"]=41;
    EZLL["Fallow Sanctuary"]=25;
    EZLH["Faol's Rest"]=-6;
    EZLL["Faol's Rest"]=-6;
    EZLH["Far Watch Post"]=14;
    EZLL["Far Watch Post"]=4;
    EZLH["Fargodeep Mine"]=20;
    EZLL["Fargodeep Mine"]=5;
    EZLH["Featherbeard's Hovel"]=42;
    EZLL["Featherbeard's Hovel"]=41;
    EZLH["Feathermoon Stronghold"]=62;
    EZLL["Feathermoon Stronghold"]=40;
    EZLH["Felfire Hill"]=30;
    EZLL["Felfire Hill"]=26;
    EZLH["Felpaw Village"]=56;
    EZLL["Felpaw Village"]=51;
    EZLH["Felstone Field"]=54;
    EZLL["Felstone Field"]=50;
    EZLH["Felwood"]=55;
    EZLL["Felwood"]=1;
    EZLH["Fenris Isle"]=31;
    EZLL["Fenris Isle"]=15;
    EZLH["Fenris Keep"]=24;
    EZLL["Fenris Keep"]=16;
    EZLH["Feral Scar Vale"]=46;
    EZLL["Feral Scar Vale"]=41;
    EZLH["Feralas"]=62;
    EZLL["Feralas"]=30;
    EZLH["Field of Giants"]=26;
    EZLL["Field of Giants"]=18;
    EZLH["Fire Plume Ridge"]=56;
    EZLL["Fire Plume Ridge"]=50;
    EZLH["Fire Scar Shrine"]=24;
    EZLL["Fire Scar Shrine"]=22;
    EZLH["Fire Stone Mesa"]=-6;
    EZLL["Fire Stone Mesa"]=-6;
    EZLH["Flame Crest"]=57;
    EZLL["Flame Crest"]=54;
    EZLH["Forest Song"]=62;
    EZLL["Forest Song"]=26;
    EZLH["Forest's Edge"]=20;
    EZLL["Forest's Edge"]=5;
    EZLH["Forgewright's Tomb"]=60;
    EZLL["Forgewright's Tomb"]=60;
    EZLH["Forlorn Ridge"]=47;
    EZLL["Forlorn Ridge"]=46;
    EZLH["Forlorn Rowe"]=35;
    EZLL["Forlorn Rowe"]=20;
    EZLH["Fray Island"]=14;
    EZLL["Fray Island"]=14;
    EZLH["Frayfeather Highlands"]=47;
    EZLL["Frayfeather Highlands"]=43;
    EZLH["Freewind Post"]=55;
    EZLL["Freewind Post"]=20;
    EZLH["Frostfire Hot Springs"]=56;
    EZLL["Frostfire Hot Springs"]=53;
    EZLH["Frostmane Hold"]=11;
    EZLL["Frostmane Hold"]=7;
    EZLH["Frostsaber Rock"]=60;
    EZLL["Frostsaber Rock"]=50;
    EZLH["Frostwhisper Gorge"]=60;
    EZLL["Frostwhisper Gorge"]=59;
    EZLH["Frostwolf Keep"]=-6;
    EZLL["Frostwolf Keep"]=-6;
    EZLH["Fungal Rock"]=55;
    EZLL["Fungal Rock"]=50;
    EZLH["Furlbrow's Pumpkin Farm"]=15;
    EZLL["Furlbrow's Pumpkin Farm"]=9;
    EZLH["Gadgetzan"]=43;
    EZLL["Gadgetzan"]=40;
    EZLH["Gahrron's Withering"]=58;
    EZLL["Gahrron's Withering"]=55;
    EZLH["Galak Crag"]=-6;
    EZLL["Galak Crag"]=-6;
    EZLH["Galak Hold"]=-6;
    EZLL["Galak Hold"]=-6;
    EZLH["Galardell Valley"]=26;
    EZLL["Galardell Valley"]=21;
    EZLH["Gallows' Corner"]=36;
    EZLL["Gallows' Corner"]=33;
    EZLH["Garren's Haunt"]=10;
    EZLL["Garren's Haunt"]=6;
    EZLH["Garrison Armory"]=50;
    EZLL["Garrison Armory"]=46;
    EZLH["Gates of Ironforge"]=8;
    EZLL["Gates of Ironforge"]=7;
    EZLH["Gavin's Naze"]=34;
    EZLL["Gavin's Naze"]=24;
    EZLH["Gelkis Village"]=36;
    EZLL["Gelkis Village"]=32;
    EZLH["Ghost Walker Post"]=50;
    EZLL["Ghost Walker Post"]=35;
    EZLH["Gillijim's Isle"]=-6;
    EZLL["Gillijim's Isle"]=-6;
    EZLH["Gnomeregan"]=35;
    EZLL["Gnomeregan"]=9;
    EZLH["Go'Shek Farm"]=38;
    EZLL["Go'Shek Farm"]=32;
    EZLH["Gol'Bolar Quarry"]=10;
    EZLL["Gol'Bolar Quarry"]=7;
    EZLH["Golakka Hot Springs"]=55;
    EZLL["Golakka Hot Springs"]=52;
    EZLH["Gold Coast Quarry"]=17;
    EZLL["Gold Coast Quarry"]=10;
    EZLH["Gold Road"]=26;
    EZLL["Gold Road"]=10;
    EZLH["Goldshire"]=6;
    EZLL["Goldshire"]=1;
    EZLH["Gordunni Outpost"]=43;
    EZLL["Gordunni Outpost"]=40;
    EZLH["Greatwood Vale"]=17;
    EZLL["Greatwood Vale"]=14;
    EZLH["Greenpaw Village"]=35;
    EZLL["Greenpaw Village"]=22;
    EZLH["Grim Batol"]=-6;
    EZLL["Grim Batol"]=-6;
    EZLH["Grimtotem Compound"]=44;
    EZLL["Grimtotem Compound"]=40;
    EZLH["Grimtotem Post"]=22;
    EZLL["Grimtotem Post"]=15;
    EZLH["Grizzlepaw Ridge"]=20;
    EZLL["Grizzlepaw Ridge"]=11;
    EZLH["Grol'dom Farm"]=16;
    EZLL["Grol'dom Farm"]=11;
    EZLH["Grom'gol Base Camp"]=60;
    EZLL["Grom'gol Base Camp"]=33;
    EZLH["Grove of the Ancients"]=19;
    EZLL["Grove of the Ancients"]=15;
    EZLH["Growless Cave"]=37;
    EZLL["Growless Cave"]=32;
    EZLH["Gunstan's Post"]=-6;
    EZLL["Gunstan's Post"]=-6;
    EZLH["Gunther's Retreat"]=9;
    EZLL["Gunther's Retreat"]=7;
    EZLH["Gurubashi Arena"]=44;
    EZLL["Gurubashi Arena"]=37;
    EZLH["Haldarr Encampment"]=53;
    EZLL["Haldarr Encampment"]=44;
    EZLH["Hammerfall"]=38;
    EZLL["Hammerfall"]=30;
    EZLH["Hammertoe'sig Site"]=-6;
    EZLL["Hammertoe'sig Site"]=-6;
    EZLH["Hammertoe'sigsite"]=39;
    EZLL["Hammertoe'sigsite"]=35;
    EZLH["Hearthglenn"]=61;
    EZLL["Hearthglenn"]=55;
    EZLH["Hearthglen"]=61;
    EZLL["Hearthglen"]=55;
    EZLH["Helm's Bed Lake"]=12;
    EZLL["Helm's Bed Lake"]=7;
    EZLH["Hetaera's Clutch"]=55;
    EZLL["Hetaera's Clutch"]=53;
    EZLH["Hidden Path"]=-6;
    EZLL["Hidden Path"]=-6;
    EZLH["High Perch"]=31;
    EZLL["High Perch"]=28;
    EZLH["High Wilderness"]=46;
    EZLL["High Wilderness"]=41;
    EZLH["Highperch"]=32;
    EZLL["Highperch"]=27;
    EZLH["Hillsbrad Fields"]=33;
    EZLL["Hillsbrad Fields"]=20;
    EZLH["Hillsbrad Foothills"]=32;
    EZLL["Hillsbrad Foothills"]=20;
    EZLH["Hillsbrad"]=30;
    EZLL["Hillsbrad"]=26;
    EZLH["Hiri'watha"]=47;
    EZLL["Hiri'watha"]=25;
    EZLH["Honor's Stand"]=18;
    EZLL["Honor's Stand"]=13;
    EZLH["Ice Thistle Hills"]=58;
    EZLL["Ice Thistle Hills"]=55;
    EZLH["Iceblood Garrison"]=-6;
    EZLL["Iceblood Garrison"]=-6;
    EZLH["Iceflow Lake"]=10;
    EZLL["Iceflow Lake"]=7;
    EZLH["Idlewind Lake"]=-6;
    EZLL["Idlewind Lake"]=-6;
    EZLH["Iris Lake"]=22;
    EZLL["Iris Lake"]=20;
    EZLH["Ironband's Compound"]=12;
    EZLL["Ironband's Compound"]=9;
    EZLH["Ironband's Excavation Site"]=22;
    EZLL["Ironband's Excavation Site"]=13;
    EZLH["Ironbeard's Tomb"]=26;
    EZLL["Ironbeard's Tomb"]=22;
    EZLH["Ironforge"]=-6;
    EZLL["Ironforge"]=-6;
    EZLH["Ironstone Plateau"]=50;
    EZLL["Ironstone Plateau"]=48;
    EZLH["Irontree Cavern"]=54;
    EZLL["Irontree Cavern"]=52;
    EZLH["Irontree Woods"]=56;
    EZLL["Irontree Woods"]=1;
    EZLH["Island ofoctor Lapidis"]=-6;
    EZLL["Island ofoctor Lapidis"]=-6;
    EZLH["Isle ofread"]=62;
    EZLL["Isle ofread"]=43;
    EZLH["Itharius's Cave"]=37;
    EZLL["Itharius's Cave"]=34;
    EZLH["Jadefire Glen"]=51;
    EZLL["Jadefire Glen"]=47;
    EZLH["Jadefire Run"]=53;
    EZLL["Jadefire Run"]=49;
    EZLH["Jademir Lake"]=62;
    EZLL["Jademir Lake"]=60;
    EZLH["Jaedenar"]=53;
    EZLL["Jaedenar"]=48;
    EZLH["Jagged Reef"]=54;
    EZLL["Jagged Reef"]=50;
    EZLH["Jaggedswine Farm"]=11;
    EZLL["Jaggedswine Farm"]=2;
    EZLH["Jaguero Isle"]=55;
    EZLL["Jaguero Isle"]=50;
    EZLH["Janeiro's Point"]=50;
    EZLL["Janeiro's Point"]=50;
    EZLH["Janerio's Point"]=-6;
    EZLL["Janerio's Point"]=-6;
    EZLH["Jangolode Mine"]=19;
    EZLL["Jangolode Mine"]=10;
    EZLH["Jasperlode Mine"]=8;
    EZLL["Jasperlode Mine"]=6;
    EZLH["Jerod's Landing"]=10;
    EZLL["Jerod's Landing"]=8;
    EZLH["Jintha'Alor"]=53;
    EZLL["Jintha'Alor"]=5;
    EZLH["Kal'ai Ruins"]=36;
    EZLL["Kal'ai Ruins"]=35;
    EZLH["Kargathia Keep"]=30;
    EZLL["Kargathia Keep"]=28;
    EZLH["Kargathia Outpost"]=-6;
    EZLL["Kargathia Outpost"]=-6;
    EZLH["Kargath"]=60;
    EZLL["Kargath"]=30;
    EZLH["Kharanos"]=30;
    EZLL["Kharanos"]=5;
    EZLH["Kodo Graveyard"]=38;
    EZLL["Kodo Graveyard"]=31;
    EZLH["Kolkar Crag"]=9;
    EZLL["Kolkar Crag"]=2;
    EZLH["Kolkar Village"]=33;
    EZLL["Kolkar Village"]=30;
    EZLH["Kormek's Hut"]=34;
    EZLL["Kormek's Hut"]=30;
    EZLH["Kurzen's Compound"]=35;
    EZLL["Kurzen's Compound"]=30;
    EZLH["Lake Everstill"]=22;
    EZLL["Lake Everstill"]=16;
    EZLH["Lake Falathim"]=20;
    EZLL["Lake Falathim"]=18;
    EZLH["Lake Kel'Theril"]=57;
    EZLL["Lake Kel'Theril"]=54;
    EZLH["Lake Mennar"]=54;
    EZLL["Lake Mennar"]=50;
    EZLH["Lake Mereldar"]=56;
    EZLL["Lake Mereldar"]=53;
    EZLH["Lake Nazferiti"]=36;
    EZLL["Lake Nazferiti"]=30;
    EZLH["Lakeridge Highway"]=19;
    EZLL["Lakeridge Highway"]=14;
    EZLH["Lakeshire"]=-6;
    EZLL["Lakeshire"]=-6;
    EZLH["Lakkari Tar Pits"]=61;
    EZLL["Lakkari Tar Pits"]=48;
    EZLH["Land's End Beach"]=50;
    EZLL["Land's End Beach"]=48;
    EZLH["Lariss Pavillion"]=46;
    EZLL["Lariss Pavillion"]=40;
    EZLH["Legash Encampment"]=51;
    EZLL["Legash Encampment"]=51;
    EZLH["Lethlor Ravine"]=57;
    EZLL["Lethlor Ravine"]=41;
    EZLH["Light's Hope Chapel"]=62;
    EZLL["Light's Hope Chapel"]=52;
    EZLH["Lighthouse"]=-6;
    EZLL["Lighthouse"]=-6;
    EZLH["Lik'ash Tar Pits"]=-6;
    EZLL["Lik'ash Tar Pits"]=-6;
    EZLH["Loch Modan"]=36;
    EZLL["Loch Modan"]=10;
    EZLH["Longshore"]=19;
    EZLL["Longshore"]=10;
    EZLH["Lordamere Internment Camp"]=36;
    EZLL["Lordamere Internment Camp"]=24;
    EZLH["Lordamere Lake"]=35;
    EZLL["Lordamere Lake"]=12;
    EZLH["Lost Point"]=37;
    EZLL["Lost Point"]=37;
    EZLH["Lost Rigger Cove"]=54;
    EZLL["Lost Rigger Cove"]=44;
    EZLH["Lower Wilds"]=65;
    EZLL["Lower Wilds"]=36;
    EZLH["Lushwater Oasis"]=30;
    EZLL["Lushwater Oasis"]=12;
    EZLH["Maestra's Post"]=42;
    EZLL["Maestra's Post"]=18;
    EZLH["Magram Village"]=37;
    EZLL["Magram Village"]=32;
    EZLH["Malaka'jin"]=30;
    EZLL["Malaka'jin"]=20;
    EZLH["Malden's Orchard"]=12;
    EZLL["Malden's Orchard"]=10;
    EZLH["Mannoroc Coven"]=40;
    EZLL["Mannoroc Coven"]=30;
    EZLH["Manor Mistmantle"]=30;
    EZLL["Manor Mistmantle"]=29;
    EZLH["Mantle Rock"]=-6;
    EZLL["Mantle Rock"]=-6;
    EZLH["Maraudon"]=50;
    EZLH["Maraudon"]=49
    EZLL["Maraudon"]=37;
    EZLL["Maraudon"]=40
    EZLH["Marshal's Refuge"]=54;
    EZLL["Marshal's Refuge"]=51;
    EZLH["Mazra'Alor"]=59;
    EZLL["Mazra'Alor"]=58;
    EZLH["Mazthoril"]=59;
    EZLL["Mazthoril"]=56;
    EZLH["Menethil Bay"]=29;
    EZLL["Menethil Bay"]=20;
    EZLH["Menethil Harbor"]=-6;
    EZLL["Menethil Harbor"]=-6;
    EZLH["Mirage Flats"]=55;
    EZLL["Mirage Flats"]=37;
    EZLH["Mirkfallon Lake"]=25;
    EZLL["Mirkfallon Lake"]=14;
    EZLH["Mirror Lake Orchard"]=6;
    EZLL["Mirror Lake Orchard"]=5;
    EZLH["Mirror Lake"]=9;
    EZLL["Mirror Lake"]=5;
    EZLH["Mist's Edge"]=21;
    EZLL["Mist's Edge"]=9;
    EZLH["Mistvale Valley"]=41;
    EZLL["Mistvale Valley"]=40;
    EZLH["Misty Pine Refuge"]=8;
    EZLL["Misty Pine Refuge"]=7;
    EZLH["Misty Reed Post"]=53;
    EZLL["Misty Reed Post"]=39;
    EZLH["Misty Reed Strand"]=53;
    EZLL["Misty Reed Strand"]=12;
    EZLH["Misty Shore"]=31;
    EZLL["Misty Shore"]=30;
    EZLH["Misty Valley"]=42;
    EZLL["Misty Valley"]=36;
    EZLH["Mizjah Ruins"]=50;
    EZLL["Mizjah Ruins"]=1;
    EZLH["Mo'grosh Stronghold"]=20;
    EZLH["Mo'Grosh Stronghold"]=20;
    EZLL["Mo'grosh Stronghold"]=18;
    EZLL["Mo'Grosh Stronghold"]=18;
    EZLH["Mok'Gordun"]=-6;
    EZLL["Mok'Gordun"]=-6;
    EZLH["Moonbrook"]=26;
    EZLL["Moonbrook"]=11;
    EZLH["Moonwell"]=27;
    EZLL["Moonwell"]=23;
    EZLH["Morgan's Vigil"]=-6;
    EZLL["Morgan's Vigil"]=-6;
    EZLH["Morlos'Aran"]=49;
    EZLL["Morlos'Aran"]=47;
    EZLH["Mosh'Ogg Ogre Mound"]=42;
    EZLL["Mosh'Ogg Ogre Mound"]=37;
    EZLH["Mosshide Fen"]=22;
    EZLL["Mosshide Fen"]=20;
    EZLH["Mulgore"]=14;
    EZLL["Mulgore"]=5;
    EZLH["Mystral Lake"]=35;
    EZLL["Mystral Lake"]=21;
    EZLH["Nek'mani Wellspring"]=44;
    EZLL["Nek'mani Wellspring"]=43;
    EZLH["Nesingwary's Expedition"]=34;
    EZLL["Nesingwary's Expedition"]=30;
    EZLH["Nethander Stead"]=32;
    EZLL["Nethander Stead"]=24;
    EZLH["Nethander Steed"]=32;
    EZLL["Nethander Steed"]=24;
    EZLH["Nethergarde Keep"]=55;
    EZLL["Nethergarde Keep"]=55;
    EZLH["Night Run"]=26;
    EZLL["Night Run"]=25;
    EZLH["Night Web's Hollow"]=5;
    EZLL["Night Web's Hollow"]=2;
    EZLH["Nightmare Vale"]=6;
    EZLL["Nightmare Vale"]=5;
    EZLH["Nightsong Woods"]=30;
    EZLL["Nightsong Woods"]=20;
    EZLH["Nijel's Point"]=45;
    EZLL["Nijel's Point"]=32;
    EZLH["Noonshade Ruins"]=43;
    EZLL["Noonshade Ruins"]=40;
    EZLH["North Gate Outpost"]=18;
    EZLL["North Gate Outpost"]=8;
    EZLH["North Point Tower"]=38;
    EZLL["North Point Tower"]=35;
    EZLH["North Tide's Hollow"]=25;
    EZLL["North Tide's Hollow"]=12;
    EZLH["North Tide's Run"]=22;
    EZLL["North Tide's Run"]=12;
    EZLH["Northdale"]=58;
    EZLL["Northdale"]=57;
    EZLH["Northfold Manor"]=36;
    EZLL["Northfold Manor"]=30;
    EZLH["Northridge Lumber Camp"]=56;
    EZLL["Northridge Lumber Camp"]=52;
    EZLH["Northshire River"]=-6;
    EZLL["Northshire River"]=-6;
    EZLH["Northshire Valley"]=10;
    EZLL["Northshire Valley"]=1;
    EZLH["Northwatch Hold"]=36;
    EZLL["Northwatch Hold"]=13;
    EZLH["O'Breen's Camp"]=-6;
    EZLL["O'Breen's Camp"]=-6;
    EZLH["Olsen's Farthing"]=13;
    EZLL["Olsen's Farthing"]=11;
    EZLH["Oneiros"]=62;
    EZLL["Oneiros"]=60;
    EZLH["Onyxia's Lair"]=-6;
    EZLL["Onyxia's Lair"]=-6;
    EZLH["Orgrimmar"]=30;
    EZLL["Orgrimmar"]=1;
    EZLH["Owl Wing Thicket"]=59;
    EZLL["Owl Wing Thicket"]=56;
    EZLH["Palemane Rock"]=8;
    EZLL["Palemane Rock"]=5;
    EZLH["Pestilent Scar"]=56;
    EZLL["Pestilent Scar"]=54;
    EZLH["Plaguewood"]=58;
    EZLL["Plaguewood"]=53;
    EZLH["Pool of Tears"]=62;
    EZLL["Pool of Tears"]=37;
    EZLH["Purgation Isle"]=31;
    EZLL["Purgation Isle"]=28;
    EZLH["Pyrewood Village"]=18;
    EZLL["Pyrewood Village"]=12;
    EZLH["Quel'Danil Lodge"]=49;
    EZLL["Quel'Danil Lodge"]=12;
    EZLH["Quel'Lithien Lodge"]=60;
    EZLL["Quel'Lithien Lodge"]=57;
    EZLH["Rage Scar Hold"]=49;
    EZLL["Rage Scar Hold"]=46;
    EZLH["Ragefire Chasm"]=15
    EZLL["Ragefire Chasm"]=13
    EZLH["Raptor Grounds"]=18;
    EZLL["Raptor Grounds"]=16;
    EZLH["Raptor Ridge"]=-6;
    EZLL["Raptor Ridge"]=-6;
    EZLH["Ratchet"]=45;
    EZLL["Ratchet"]=13;
    EZLH["Ravaged Caravan"]=12;
    EZLL["Ravaged Caravan"]=6;
    EZLH["Raven Hill Cemetery"]=35;
    EZLL["Raven Hill Cemetery"]=19;
    EZLH["Raven Hill"]=26;
    EZLL["Raven Hill"]=18;
    EZLH["Ravencrest Monument"]=55;
    EZLL["Ravencrest Monument"]=53;
    EZLH["Raynewood Retreat"]=35;
    EZLL["Raynewood Retreat"]=21;
    EZLH["Razor Hill Barracks"]=32;
    EZLL["Razor Hill Barracks"]=14;
    EZLH["Razor Hill"]=35;
    EZLL["Razor Hill"]=1;
    EZLH["Razorfen Downs"]=40
    EZLL["Razorfen Downs"]=35
    EZLH["Razorfen Kraul"]=34;
    EZLH["Razorfen Kraul"]=31
    EZLL["Razorfen Kraul"]=12;
    EZLL["Razorfen Kraul"]=25
    EZLH["Razorfenowns"]=40;
    EZLL["Razorfenowns"]=23;
    EZLH["Razormane Grounds"]=32;
    EZLL["Razormane Grounds"]=1;
    EZLH["Razorwind Canyon"]=8;
    EZLL["Razorwind Canyon"]=4;
    EZLH["Rebel Camp"]=31;
    EZLL["Rebel Camp"]=30;
    EZLH["Red Cloud Mesa"]=7;
    EZLL["Red Cloud Mesa"]=1;
    EZLH["Red Rocks"]=10;
    EZLL["Red Rocks"]=7;
    EZLH["Redridge Canyons"]=25;
    EZLL["Redridge Canyons"]=16;
    EZLH["Redridge Mountains"]=35;
    EZLL["Redridge Mountains"]=14;
    EZLH["Refuge Pointe"]=39;
    EZLL["Refuge Pointe"]=30;
    EZLH["Remtravel's Excavation Site"]=20;
    EZLL["Remtravel's Excavation Site"]=18;
    EZLH["Remtravel's Excavation"]=20;
    EZLL["Remtravel's Excavation"]=15;
    EZLH["Render's Camp"]=25;
    EZLL["Render's Camp"]=16;
    EZLH["Render's Rock"]=25;
    EZLL["Render's Rock"]=19;
    EZLH["Render's Valley"]=22;
    EZLL["Render's Valley"]=17;
    EZLH["Rethban Caverns"]=24;
    EZLL["Rethban Caverns"]=17;
    EZLH["Ridgepoint Tower"]=11;
    EZLL["Ridgepoint Tower"]=8;
    EZLH["Rise of theefiler"]=53;
    EZLL["Rise of theefiler"]=45;
    EZLH["Rocktusk Farm"]=11;
    EZLL["Rocktusk Farm"]=5;
    EZLH["Roguefeatheren"]=31;
    EZLL["Roguefeatheren"]=28;
    EZLH["Roland'soom"]=31;
    EZLL["Roland'soom"]=30;
    EZLH["Ruins of Aboraz"]=44;
    EZLL["Ruins of Aboraz"]=43;
    EZLH["Ruins of Alterac"]=49;
    EZLL["Ruins of Alterac"]=32;
    EZLH["Ruins of Anderhol"]=60;
    EZLL["Ruins of Anderhol"]=50;
    EZLH["Ruins of Andorhal"]=61;
    EZLL["Ruins of Andorhal"]=52;
    EZLH["Ruins of Constellas"]=54;
    EZLL["Ruins of Constellas"]=47;
    EZLH["Ruins of Eldarath"]=53;
    EZLL["Ruins of Eldarath"]=46;
    EZLH["Ruins of Isildien"]=47;
    EZLL["Ruins of Isildien"]=41;
    EZLH["Ruins of Jubuwal"]=44;
    EZLL["Ruins of Jubuwal"]=43;
    EZLH["Ruins of Lordaeron"]=15;
    EZLL["Ruins of Lordaeron"]=6;
    EZLH["Ruins of Mathyrstra"]=21;
    EZLL["Ruins of Mathyrstra"]=18;
    EZLH["Ruins of Mathystra"]=21;
    EZLL["Ruins of Mathystra"]=17;
    EZLH["Ruins of Ravenwind"]=50;
    EZLL["Ruins of Ravenwind"]=47;
    EZLH["Ruins of Solarsal"]=43;
    EZLL["Ruins of Solarsal"]=40;
    EZLH["Ruins of Thaurisan"]=57;
    EZLL["Ruins of Thaurisan"]=50;
    EZLH["Ruins of Thaurissan"]=57;
    EZLL["Ruins of Thaurissan"]=50;
    EZLH["Ruins of Zul'Kunda"]=41;
    EZLL["Ruins of Zul'Kunda"]=32;
    EZLH["Ruins of Zul'Mamwe"]=45;
    EZLL["Ruins of Zul'Mamwe"]=37;
    EZLH["Ruins of Zulmamwe"]=45;
    EZLL["Ruins of Zulmamwe"]=37;
    EZLH["Saldean's Farm"]=19;
    EZLL["Saldean's Farm"]=10;
    EZLH["Saltspray Glen"]=26;
    EZLL["Saltspray Glen"]=23;
    EZLH["Sandsorrow Watch"]=48;
    EZLL["Sandsorrow Watch"]=41;
    EZLH["Sar'theris Strand"]=55;
    EZLL["Sar'theris Strand"]=30;
    EZLH["Sardor Isle"]=-6;
    EZLL["Sardor Isle"]=-6;
    EZLH["Sargeron"]=-6;
    EZLL["Sargeron"]=-6;
    EZLH["Satyrnaar"]=30;
    EZLL["Satyrnaar"]=26;
    EZLL["sBaldar"]=-6;
    EZLH["Scarlet Base Camp"]=54;
    EZLL["Scarlet Base Camp"]=53;
    EZLH["Scarlet Monastery"]=40;
    EZLL["Scarlet Monastery"]=29;
    EZLH["Scarlet Watch Post"]=12;
    EZLL["Scarlet Watch Post"]=8;
    EZLH["Scholomance"]=-6;
    EZLH["Scholomance"]=60
    EZLL["Scholomance"]=-6;
    EZLL["Scholomance"]=57
    EZLH["Scrabblescrew's Camp"]=38;
    EZLL["Scrabblescrew's Camp"]=34;
    EZLH["Scuttle Coast"]=13;
    EZLL["Scuttle Coast"]=1;
    EZLH["Searing Gorge"]=58;
    EZLL["Searing Gorge"]=43;
    EZLH["Sen'jin Village"]=50;
    EZLL["Sen'jin Village"]=1;
    EZLH["Sentinel Hill"]=30;
    EZLL["Sentinel Hill"]=10;
    EZLH["Sentry Point"]=34;
    EZLL["Sentry Point"]=32;
    EZLH["Seradane"]=62;
    EZLL["Seradane"]=60;
    EZLH["Serpent's Coil"]=55;
    EZLL["Serpent's Coil"]=47;
    EZLH["Shadow Hold"]=59;
    EZLL["Shadow Hold"]=50;
    EZLH["Shadowfang Keep"]=27;
    EZLH["Shadowfang Keep"]=25
    EZLL["Shadowfang Keep"]=13;
    EZLL["Shadowfang Keep"]=18
    EZLH["Shadowfang"]=-6;
    EZLL["Shadowfang"]=-6;
    EZLH["Shadowprey Village"]=60;
    EZLL["Shadowprey Village"]=10;
    EZLH["Shadowsong Shrine"]=48;
    EZLL["Shadowsong Shrine"]=45;
    EZLH["Shadra'Alor"]=55;
    EZLL["Shadra'Alor"]=25;
    EZLH["Shady Rest Inn"]=-6;
    EZLL["Shady Rest Inn"]=-6;
    EZLH["Shatter Scar Vale"]=54;
    EZLL["Shatter Scar Vale"]=49;
    EZLH["Shell Beach"]=-6;
    EZLL["Shell Beach"]=-6;
    EZLH["Shimmer Ridge"]=10;
    EZLL["Shimmer Ridge"]=7;
    EZLH["Shindigger's Camp"]=46;
    EZLL["Shindigger's Camp"]=45;
    EZLH["Shrine of the Dormant Flame"]=12;
    EZLL["Shrine of the Dormant Flame"]=12;
    EZLH["Shrine of the fallen warrior"]=14;
    EZLH["Shrine of the Fallen Warrior"]=14;
    EZLL["Shrine of the fallen warrior"]=12;
    EZLL["Shrine of the Fallen Warrior"]=12;
    EZLH["Shrine of theeceiver"]=52;
    EZLL["Shrine of theeceiver"]=50;
    EZLH["Silver Stream Mine"]=15;
    EZLL["Silver Stream Mine"]=10;
    EZLH["Silverpine Forest"]=25;
    EZLL["Silverpine Forest"]=10;
    EZLH["Silverwind Refuge"]=40;
    EZLL["Silverwind Refuge"]=40;
    EZLH["Silverwing Outpost"]=24;
    EZLL["Silverwing Outpost"]=21;
    EZLH["Sishir Canyon"]=22;
    EZLL["Sishir Canyon"]=14;
    EZLH["Skulk Rock"]=48;
    EZLL["Skulk Rock"]=46;
    EZLH["Skull Rock"]=14;
    EZLL["Skull Rock"]=5;
    EZLH["Skyline Ridge"]=-6;
    EZLL["Skyline Ridge"]=-6;
    EZLH["Slaughter Hollow"]=-6;
    EZLL["Slaughter Hollow"]=-6;
    EZLH["Slither Rock"]=60;
    EZLL["Slither Rock"]=50;
    EZLH["Sofera's Naze"]=35;
    EZLL["Sofera's Naze"]=32;
    EZLH["Solace Glade"]=-6;
    EZLL["Solace Glade"]=-6;
    EZLH["Solliden Farmstead"]=7;
    EZLL["Solliden Farmstead"]=5;
    EZLH["Sorrow Hill"]=57;
    EZLL["Sorrow Hill"]=50;
    EZLH["Sorrowmurk"]=62;
    EZLL["Sorrowmurk"]=37;
    EZLH["South Gate Outpost"]=10;
    EZLL["South Gate Outpost"]=9;
    EZLH["South Gate Pass"]=10;
    EZLL["South Gate Pass"]=9;
    EZLH["South Tide's Run"]=-6;
    EZLL["South Tide's Run"]=-6;
    EZLH["Southbreak Shore"]=50;
    EZLL["Southbreak Shore"]=48;
    EZLH["Southern Barrens"]=45;
    EZLL["Southern Barrens"]=8;
    EZLH["Southern Gold Road"]=34;
    EZLL["Southern Gold Road"]=14;
    EZLH["Southern Savage Coast"]=44;
    EZLL["Southern Savage Coast"]=39;
    EZLH["Southfury River"]=48;
    EZLL["Southfury River"]=4;
    EZLH["Southmoon Ruins"]=50;
    EZLL["Southmoon Ruins"]=43;
    EZLH["Southpoint Tower"]=22;
    EZLL["Southpoint Tower"]=21;
    EZLH["Southridge Beach"]=55;
    EZLL["Southridge Beach"]=50;
    EZLH["Southshore"]=38;
    EZLL["Southshore"]=22;
    EZLH["Spirit Rock"]=15;
    EZLL["Spirit Rock"]=13;
    EZLH["Spiriten"]=44;
    EZLL["Spiriten"]=40;
    EZLH["Splinterspear Junction"]=37;
    EZLL["Splinterspear Junction"]=34;
    EZLH["Splintertree Post"]=44;
    EZLL["Splintertree Post"]=26;
    EZLH["Splithoof Crag"]=27;
    EZLL["Splithoof Crag"]=24;
    EZLH["Splithoof Hold"]=30;
    EZLL["Splithoof Hold"]=24;
    EZLH["Stagalbog Cave"]=55;
    EZLL["Stagalbog Cave"]=40;
    EZLH["Stagalbog"]=55;
    EZLL["Stagalbog"]=30;
    EZLH["Stanglethorn Vale"]=55;
    EZLL["Stanglethorn Vale"]=30;
    EZLH["Starfall Village"]=56;
    EZLL["Starfall Village"]=54;
    EZLH["Steamwheedle Port"]=53;
    EZLL["Steamwheedle Port"]=30;
    EZLH["Steelgrill'sepot"]=8;
    EZLL["Steelgrill'sepot"]=5;
    EZLH["Stendel's Pond"]=17;
    EZLL["Stendel's Pond"]=11;
    EZLH["Stillwater Pond"]=8;
    EZLL["Stillwater Pond"]=5;
    EZLH["Stonard"]=60;
    EZLL["Stonard"]=30;
    EZLH["Stone Cairn Lake"]=10;
    EZLL["Stone Cairn Lake"]=7;
    EZLH["Stonebull Lake"]=14;
    EZLL["Stonebull Lake"]=5;
    EZLH["Stonesplinter Valley"]=17;
    EZLL["Stonesplinter Valley"]=11;
    EZLH["Stonetalon Mountains"]=24;
    EZLL["Stonetalon Mountains"]=21;
    EZLH["Stonetalon Peak"]=27;
    EZLL["Stonetalon Peak"]=22;
    EZLH["Stonewatch Falls"]=22;
    EZLL["Stonewatch Falls"]=19;
    EZLH["Stonewatch Keep"]=26;
    EZLL["Stonewatch Keep"]=21;
    EZLH["Stonewatch Tower"]=26;
    EZLL["Stonewatch Tower"]=16;
    EZLH["Stonewatch"]=26;
    EZLL["Stonewatch"]=20;
    EZLH["Stonewrought Pass"]=-6;
    EZLL["Stonewrought Pass"]=-6;
    EZLH["Stonewroughtam"]=30;
    EZLL["Stonewroughtam"]=10;
    EZLH["Stormwind City"]=-6;
    EZLL["Stormwind City"]=-6;
    EZLH["Strahnbrad"]=37;
    EZLL["Strahnbrad"]=34;
    EZLL["Stranglethorn Vale"]=30;
    EZLH["Stranglethorn Vale"]=45;
    EZLH["Strathome"]=60;
    EZLL["Strathome"]=55;
    EZLH["Stromgarde Keep"]=40;
    EZLL["Stromgarde Keep"]=35;
    EZLH["Sun Rock Retreat"]=55;
    EZLL["Sun Rock Retreat"]=17;
    EZLH["Sundown Marsh"]=26;
    EZLL["Sundown Marsh"]=21;
    EZLH["Swamp of Sorrows"]=62;
    EZLL["Swamp of Sorrows"]=25;
    EZLH["Talonbranch Glade"]=53;
    EZLL["Talonbranch Glade"]=52;
    EZLH["Tanaris"]=50;
    EZLL["Tanaris"]=40;
    EZLH["Tarren Mill"]=56;
    EZLL["Tarren Mill"]=20;
    EZLH["Teldrassil"]=10;
    EZLL["Teldrassil"]=1;
    EZLH["Temple of Arkkoran"]=60;
    EZLL["Temple of Arkkoran"]=53;
    EZLH["Temple of Zin-Malor"]=55;
    EZLL["Temple of Zin-Malor"]=48;
    EZLH["Terrace of Repose"]=30;
    EZLL["Terrace of Repose"]=29;
    EZLH["Terror Run"]=55;
    EZLL["Terror Run"]=50;
    EZLH["Terror Wing Path"]=55;
    EZLL["Terror Wing Path"]=50;
    EZLH["Terrordale"]=58;
    EZLL["Terrordale"]=53;
    EZLH["Tethris Aran"]=-6;
    EZLL["Tethris Aran"]=-6;
    EZLH["Thalanaar"]=-6;
    EZLL["Thalanaar"]=-6;
    EZLH["Thalassian Base Camp"]=53;
    EZLL["Thalassian Base Camp"]=51;
    EZLH["Thandol Span"]=22;
    EZLL["Thandol Span"]=22;
    EZLH["The Altar of Zul"]=52;
    EZLL["The Altar of Zul"]=44;
    EZLH["The Barrens"]=35;
    EZLL["The Barrens"]=5;
    EZLH["The Bulwark"]=60;
    EZLL["The Bulwark"]=50;
    EZLH["The Cape of Stranglethorn"]=55;
    EZLL["The Cape of Stranglethorn"]=37;
    EZLH["The Cemetary"]=-6;
    EZLL["The Cemetary"]=-6;
    EZLH["The Charred Vale"]=30;
    EZLL["The Charred Vale"]=23;
    EZLH["The Creeping Ruin"]=46;
    EZLL["The Creeping Ruin"]=44;
    EZLH["The Crossroads"]=55;
    EZLL["The Crossroads"]=10;
    EZLH["The Crystal Shore"]=47;
    EZLL["The Crystal Shore"]=40;
    EZLH["The Farstrider Lodge"]=15;
    EZLL["The Farstrider Lodge"]=15;
    EZLH["The Foothill Caverns"]=-6;
    EZLL["The Foothill Caverns"]=-6;
    EZLH["The Forgotten Coast"]=49;
    EZLL["The Forgotten Coast"]=41;
    EZLH["The Forgotten Pools"]=17;
    EZLL["The Forgotten Pools"]=12;
    EZLH["The Fungal Vale"]=59;
    EZLL["The Fungal Vale"]=57;
    EZLH["The Gaping Chasm"]=50;
    EZLL["The Gaping Chasm"]=44;
    EZLH["The Golden Plains"]=12;
    EZLL["The Golden Plains"]=6;
    EZLH["The Great Lift"]=27;
    EZLL["The Great Lift"]=25;
    EZLH["The Green Belt"]=27;
    EZLL["The Green Belt"]=21;
    EZLH["The Greymane Wall"]=25;
    EZLL["The Greymane Wall"]=15;
    EZLH["The Grinding Quarry"]=50;
    EZLL["The Grinding Quarry"]=47;
    EZLL["The Grizzleden"]=5-7;
    EZLH["The Harborage"]=42;
    EZLL["The Harborage"]=35;
    EZLH["The Headland"]=34;
    EZLL["The Headland"]=23;
    EZLH["The Hidden Grove"]=58;
    EZLL["The Hidden Grove"]=56;
    EZLH["The Hinterlands"]=48;
    EZLL["The Hinterlands"]=12;
    EZLH["The Howling Vale"]=-6;
    EZLL["The Howling Vale"]=-6;
    EZLH["The Hushed Bank"]=22;
    EZLL["The Hushed Bank"]=18;
    EZLH["The Infectis Scar"]=56;
    EZLL["The Infectis Scar"]=54;
    EZLH["The Ivar Patch"]=15;
    EZLL["The Ivar Patch"]=11;
    EZLH["The Jansen Stead"]=13;
    EZLL["The Jansen Stead"]=9;
    EZLH["The Loch"]=22;
    EZLL["The Loch"]=10;
    EZLH["The Long Wash"]=16;
    EZLL["The Long Wash"]=9;
    EZLH["The Lost Fleet"]=28;
    EZLL["The Lost Fleet"]=21;
    EZLH["The Maclure Vineyards"]=20;
    EZLL["The Maclure Vineyards"]=5;
    EZLH["The Maker's Terrace"]=37;
    EZLL["The Maker's Terrace"]=35;
    EZLH["The Marris Stead"]=62;
    EZLL["The Marris Stead"]=53;
    EZLH["The Marshlands"]=61;
    EZLL["The Marshlands"]=48;
    EZLH["The Masonary"]=50;
    EZLL["The Masonary"]=48;
    EZLH["The Master's Glaive"]=20;
    EZLL["The Master's Glaive"]=16;
    EZLH["The Merchant Coast"]=38;
    EZLL["The Merchant Coast"]=12;
    EZLH["The Molsen Farm"]=19;
    EZLL["The Molsen Farm"]=10;
    EZLH["The Molten Span"]=49;
    EZLL["The Molten Span"]=48;
    EZLH["The Mor'shan Rampart"]=21;
    EZLL["The Mor'shan Rampart"]=11;
    EZLH["The North Coast"]=9;
    EZLL["The North Coast"]=7;
    EZLH["The Noxious Lair"]=50;
    EZLL["The Noxious Lair"]=44;
    EZLH["The Overlook Cliffs"]=50;
    EZLL["The Overlook Cliffs"]=30;
    EZLH["The Pillar of Ash"]=57;
    EZLL["The Pillar of Ash"]=55;
    EZLH["The Quagmire"]=45;
    EZLL["The Quagmire"]=36;
    EZLH["The Rolling Plains"]=12;
    EZLL["The Rolling Plains"]=5;
    EZLH["The Rotting Orchard"]=29;
    EZLL["The Rotting Orchard"]=26;
    EZLH["The Ruined Reaches"]=55;
    EZLL["The Ruined Reaches"]=45;
    EZLH["The Ruins of Kel'Theril"]=56;
    EZLL["The Ruins of Kel'Theril"]=54;
    EZLH["The Ruins of Lordaeron"]=13;
    EZLL["The Ruins of Lordaeron"]=6;
    EZLH["The Ruins of Ordil'Aran"]=19;
    EZLL["The Ruins of Ordil'Aran"]=18;
    EZLH["The Ruins of Stardust"]=24;
    EZLL["The Ruins of Stardust"]=21;
    EZLH["The Rustmaulig Site"]=35;
    EZLL["The Rustmaulig Site"]=32;
    EZLH["The Salty Sailor"]=50;
    EZLL["The Salty Sailor"]=50;
    EZLH["The Sanctum"]=44;
    EZLL["The Sanctum"]=39;
    EZLH["The Savage Coast"]=55;
    EZLL["The Savage Coast"]=31;
    EZLH["The Scarlet Monastery"]=40
    EZLL["The Scarlet Monastery"]=30
    EZLH["The Screeching Canyon"]=30;
    EZLL["The Screeching Canyon"]=26;
    EZLH["The Sepulcher"]=22;
    EZLL["The Sepulcher"]=10;
    EZLH["The Shady Nook"]=26;
    EZLL["The Shady Nook"]=24;
    EZLH["The Shattered Strand"]=52;
    EZLL["The Shattered Strand"]=50;
    EZLH["The Shifting Mire"]=55;
    EZLL["The Shifting Mire"]=34;
    EZLH["The Shimmering Flats"]=37;
    EZLL["The Shimmering Flats"]=27;
    EZLH["The Shining Strand"]=19;
    EZLL["The Shining Strand"]=10;
    EZLH["The Shrine of Aessina"]=27;
    EZLL["The Shrine of Aessina"]=17;
    EZLH["The Skitteringark"]=15;
    EZLL["The Skitteringark"]=12;
    EZLH["The Slithering Scar"]=53;
    EZLL["The Slithering Scar"]=48;
    EZLH["The Sludge Fen"]=19;
    EZLL["The Sludge Fen"]=13;
    EZLH["The Stagnant Oasis"]=18;
    EZLL["The Stagnant Oasis"]=12;
    EZLH["The Stockades"]=26
    EZLL["The Stockades"]=23
    EZLH["The Stonefield Farm"]=9;
    EZLL["The Stonefield Farm"]=5;
    EZLH["The Sunken Temple"]=50
    EZLL["The Sunken Temple"]=44
    EZLH["The Tainted Scar"]=61;
    EZLL["The Tainted Scar"]=61;
    EZLH["The Talondeep Path"]=25;
    EZLL["The Talondeep Path"]=14;
    EZLH["The Talonen"]=30;
    EZLL["The Talonen"]=22;
    EZLH["The Tidus Stair"]=36;
    EZLL["The Tidus Stair"]=13;
    EZLH["The Tower of Arathor"]=40;
    EZLL["The Tower of Arathor"]=37;
    EZLH["The Tundrid Hills"]=12;
    EZLL["The Tundrid Hills"]=5;
    EZLH["The Twin Colossals"]=50;
    EZLL["The Twin Colossals"]=44;
    EZLH["The Undercroft"]=55;
    EZLL["The Undercroft"]=53;
    EZLH["The Uplands"]=37;
    EZLL["The Uplands"]=30;
    EZLH["The Veiled Sea"]=35;
    EZLL["The Veiled Sea"]=33;
    EZLH["The Venture Co. Mine"]=12;
    EZLL["The Venture Co. Mine"]=6;
    EZLH["The Vile Reef"]=40;
    EZLL["The Vile Reef"]=35;
    EZLH["The Wailing Caverns"]=27;
    EZLL["The Wailing Caverns"]=15;
    EZLH["The Weathered Nook"]=-6;
    EZLL["The Weathered Nook"]=-6;
    EZLH["The Whipple Estate"]=-6;
    EZLL["The Whipple Estate"]=-6;
    EZLH["The World Tree"]=-6;
    EZLL["The World Tree"]=-6;
    EZLH["The Writhing Haunt"]=55;
    EZLL["The Writhing Haunt"]=52;
    EZLH["The Writhingeep"]=46;
    EZLL["The Writhingeep"]=42;
    EZLH["The Yorgen Farmstead"]=35;
    EZLL["The Yorgen Farmstead"]=23;
    EZLH["The Zoram Strand"]=40;
    EZLL["The Zoram Strand"]=18;
    EZLH["Theagger Hills"]=30;
    EZLL["Theagger Hills"]=15;
    EZLH["Thearkened Bank"]=21;
    EZLL["Thearkened Bank"]=9;
    EZLH["Theawning Isles"]=31;
    EZLL["Theawning Isles"]=15;
    EZLH["Theead Acre"]=26;
    EZLL["Theead Acre"]=16;
    EZLH["Theead Field"]=14;
    EZLL["Theead Field"]=11;
    EZLH["Theeadmines"]=22;
    EZLL["Theeadmines"]=15;
    EZLH["Theecrepit Ferry"]=16;
    EZLL["Theecrepit Ferry"]=13;
    EZLH["Thelgen Rock"]=22;
    EZLL["Thelgen Rock"]=20;
    EZLH["Thelsamar"]=30;
    EZLL["Thelsamar"]=10;
    EZLH["Theor'Danil Barrowen"]=32;
    EZLL["Theor'Danil Barrowen"]=19;
    EZLH["Theragonmurk"]=45;
    EZLL["Theragonmurk"]=37;
    EZLH["Theramore Isle"]=55;
    EZLL["Theramore Isle"]=35;
    EZLH["Therowned Reef"]=39;
    EZLL["Therowned Reef"]=39;
    EZLH["Thery Hills"]=20;
    EZLL["Thery Hills"]=13;
    EZLH["Theust Plains"]=24;
    EZLL["Theust Plains"]=15;
    EZLH["Theustbowl"]=55;
    EZLL["Theustbowl"]=36;
    EZLH["Thieves Camp"]=-6;
    EZLL["Thieves Camp"]=-6;
    EZLH["Thistlefur Village"]=25;
    EZLL["Thistlefur Village"]=20;
    EZLH["Thistleshrub Valley"]=50;
    EZLL["Thistleshrub Valley"]=47;
    EZLH["Thondroril River"]=56;
    EZLL["Thondroril River"]=53;
    EZLH["Thoradin's Wall"]=33;
    EZLL["Thoradin's Wall"]=24;
    EZLH["Thorn Hill"]=19;
    EZLL["Thorn Hill"]=10;
    EZLH["Thousand Needles"]=42;
    EZLL["Thousand Needles"]=10;
    EZLH["Three Corners"]=35;
    EZLL["Three Corners"]=14;
    EZLH["Thunder Axe Fortress"]=32;
    EZLL["Thunder Axe Fortress"]=30;
    EZLH["Thunder Bluff"]=75;
    EZLL["Thunder Bluff"]=3;
    EZLH["Thunder Falls"]=-6;
    EZLL["Thunder Falls"]=-6;
    EZLH["Thunder Ridge"]=12;
    EZLL["Thunder Ridge"]=2;
    EZLH["Thunderbrewistillery"]=30;
    EZLL["Thunderbrewistillery"]=30;
    EZLH["Thunderhorn Water Well"]=12;
    EZLL["Thunderhorn Water Well"]=6;
    EZLH["Tidefury Cove"]=43;
    EZLL["Tidefury Cove"]=42;
    EZLH["Timbermaw Hold"]=55;
    EZLL["Timbermaw Hold"]=48;
    EZLH["Timbermaw Post"]=56;
    EZLL["Timbermaw Post"]=53;
    EZLH["Tiragarde Keep"]=9;
    EZLL["Tiragarde Keep"]=1;
    EZLH["Tirisfal Glades"]=45;
    EZLL["Tirisfal Glades"]=5;
    EZLH["Tkashi Ruins"]=37;
    EZLL["Tkashi Ruins"]=30;
    EZLH["Tower of Althalaxx"]=28;
    EZLL["Tower of Althalaxx"]=16;
    EZLH["Tower of Azora"]=8;
    EZLL["Tower of Azora"]=6;
    EZLH["Tower of Eldara"]=-6;
    EZLL["Tower of Eldara"]=-6;
    EZLH["Tower of Ilgalar"]=26;
    EZLL["Tower of Ilgalar"]=25;
    EZLH["Tranquil Gardens Cemetery"]=30;
    EZLL["Tranquil Gardens Cemetery"]=21;
    EZLH["Twilight Grove"]=-6;
    EZLL["Twilight Grove"]=-6;
    EZLH["Twilight Shore"]=21;
    EZLL["Twilight Shore"]=10;
    EZLH["Twilight Vale"]=20;
    EZLL["Twilight Vale"]=10;
    EZLH["Uldaman"]=50;
    EZLH["Uldaman"]=45
    EZLL["Uldaman"]=35;
    EZLL["Uldaman"]=35
    EZLH["Uldum"]=49;
    EZLL["Uldum"]=48;
    EZLH["Un'Goro Crater"]=61;
    EZLL["Un'Goro Crater"]=48;
    EZLH["Ursolan"]=52;
    EZLL["Ursolan"]=50;
    EZLH["Valgan's Field"]=14;
    EZLL["Valgan's Field"]=10;
    EZLH["Valley of Bones"]=40;
    EZLL["Valley of Bones"]=37;
    EZLH["Valley of Fangs"]=42;
    EZLL["Valley of Fangs"]=35;
    EZLH["Valley of Heroes"]=-6;
    EZLL["Valley of Heroes"]=-6;
    EZLH["Valley of Kings"]=12;
    EZLL["Valley of Kings"]=11;
    EZLH["Valley of Spears"]=42;
    EZLL["Valley of Spears"]=37;
    EZLH["Valley of the Bloodfuries"]=-6;
    EZLL["Valley of the Bloodfuries"]=-6;
    EZLH["Valley of the Watchers"]=49;
    EZLL["Valley of the Watchers"]=43;
    EZLH["Valley of Trials"]=35;
    EZLL["Valley of Trials"]=1;
    EZLH["Valormok"]=55;
    EZLL["Valormok"]=45;
    EZLH["Valorwind Lake"]=47;
    EZLL["Valorwind Lake"]=43;
    EZLH["Vanndir Encampment"]=-6;
    EZLL["Vanndir Encampment"]=-6;
    EZLH["Venomweb Vale"]=30;
    EZLL["Venomweb Vale"]=8;
    EZLH["Venture Co. Base Camp"]=42;
    EZLL["Venture Co. Base Camp"]=31;
    EZLH["Venture Co. Operations Center"]=38;
    EZLL["Venture Co. Operations Center"]=31;
    EZLH["Verdantis River"]=46;
    EZLL["Verdantis River"]=42;
    EZLH["Vul'Gol Ogre Mound"]=30;
    EZLL["Vul'Gol Ogre Mound"]=27;
    EZLH["Wailing Caverns"]=16;
    EZLH["Wailing Caverns"]=21
    EZLL["Wailing Caverns"]=12;
    EZLL["Wailing Caverns"]=15
    EZLH["Warsong Lumber Camp"]=29;
    EZLL["Warsong Lumber Camp"]=25;
    EZLH["Waterspring Field"]=46;
    EZLL["Waterspring Field"]=40;
    EZLH["Wavestrider Beach"]=45;
    EZLL["Wavestrider Beach"]=40;
    EZLH["Webwinder Path"]=30;
    EZLL["Webwinder Path"]=15;
    EZLH["West Pillar"]=-6;
    EZLL["West Pillar"]=-6;
    EZLH["Westbrook Garrison"]=9;
    EZLL["Westbrook Garrison"]=5;
    EZLH["Western Plaguelands"]=63;
    EZLL["Western Plaguelands"]=50;
    EZLH["Western Strand"]=32;
    EZLL["Western Strand"]=24;
    EZLH["Westfall Lighthouse"]=-6;
    EZLL["Westfall Lighthouse"]=-6;
    EZLH["Westfall"]=19;
    EZLL["Westfall"]=9;
    EZLH["Wetlands"]=27;
    EZLL["Wetlands"]=20;
    EZLH["Whelgar's Excavation Site"]=29;
    EZLL["Whelgar's Excavation Site"]=22;
    EZLH["Whispering Gardens"]=30;
    EZLL["Whispering Gardens"]=10;
    EZLH["Whispering Shore"]=-6;
    EZLL["Whispering Shore"]=-6;
    EZLH["Whitereach Post"]=42;
    EZLL["Whitereach Post"]=24;
    EZLH["Wild Shore"]=52;
    EZLL["Wild Shore"]=40;
    EZLH["Wildbend River"]=14;
    EZLL["Wildbend River"]=13;
    EZLH["Wildhammer Keep"]=45;
    EZLL["Wildhammer Keep"]=45;
    EZLH["Wildmane Water Well"]=10;
    EZLL["Wildmane Water Well"]=8;
    EZLH["Wildwind Lake"]=46;
    EZLL["Wildwind Lake"]=43;
    EZLH["Windbreak Canyon"]=29;
    EZLL["Windbreak Canyon"]=27;
    EZLH["Windfury Ridge"]=11;
    EZLL["Windfury Ridge"]=8;
    EZLH["Windshear Crag"]=23;
    EZLL["Windshear Crag"]=14;
    EZLH["Windshear Mine"]=22;
    EZLL["Windshear Mine"]=20;
    EZLH["Winterfall Village"]=59;
    EZLL["Winterfall Village"]=55;
    EZLH["Winterhoof Water Well"]=8;
    EZLL["Winterhoof Water Well"]=5;
    EZLH["Winterspring"]=60;
    EZLL["Winterspring"]=53;
    EZLH["Witch Hill"]=38;
    EZLL["Witch Hill"]=35;
    EZLH["Witherbark Village"]=37;
    EZLL["Witherbark Village"]=31;
    EZLH["Woodpaw Hills"]=46;
    EZLL["Woodpaw Hills"]=40;
    EZLH["Woodpawen"]=44;
    EZLL["Woodpawen"]=42;
    EZLH["Xavian"]=30;
    EZLL["Xavian"]=25;
    EZLH["Zalashji's Den"]=-6;
    EZLL["Zalashji's Den"]=-6;
    EZLH["Ziata'jai Ruins"]=40;
    EZLL["Ziata'jai Ruins"]=37;
    EZLH["Zoram'gar Outpost"]=35;
    EZLL["Zoram'gar Outpost"]=18;
    EZLH["Zul Gurub"]=-6;
    EZLL["Zul Gurub"]=-6;
    EZLH["Zul'Farrak"]=48;
    EZLH["Zul'Farrak"]=47
    EZLL["Zul'Farrak"]=30;
    EZLL["Zul'Farrak"]=43
    EZLH["Zul'Mashar"]=59;
    EZLL["Zul'Mashar"]=57;
    EZLH["Zun'watha"]=42;
    EZLL["Zun'watha"]=40;
    EZLH["Zuuldaia Ruins"]=38;
    EZLH["Zuuldaia Ruins"]=38;
    EZLL["Zuuldaia Ruins"]=35;
    EZLL["Zuuldaia Ruins"]=35;
end
